@@ -1,5 +1,6 @@
-# -*- coding: utf-8 -*-
 from plone.app.contentmenu.interfaces import IContentMenuView
+from plone.base.interfaces.controlpanel import ISiteSchema
+from plone.registry.interfaces import IRegistry
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from zope.browsermenu.interfaces import IBrowserMenu
 from zope.component import getUtility
@@ -9,10 +10,9 @@ from zope.interface import implementer
 
 @implementer(IContentMenuView)
 class ContentMenuProvider(ContentProviderBase):
-    """Content menu provider for the "view" tab: displays the menu
-    """
+    """Content menu provider for the "view" tab: displays the menu"""
 
-    index = ViewPageTemplateFile('contentmenu.pt')
+    index = ViewPageTemplateFile("contentmenu.pt")
 
     def render(self):
         return self.index()
@@ -22,7 +22,12 @@ class ContentMenuProvider(ContentProviderBase):
     def available(self):
         return True
 
+    def toolbar_position(self):
+        registry = getUtility(IRegistry)
+        settings = registry.forInterface(ISiteSchema, prefix="plone", check=False)
+        return settings.toolbar_position
+
     def menu(self):
-        menu = getUtility(IBrowserMenu, name='plone_contentmenu')
+        menu = getUtility(IBrowserMenu, name="plone_contentmenu")
         items = menu.getMenuItems(self.context, self.request)
         return items
